hgext/mq.py
changeset 16192 a4413624d014
parent 16152 816211dfa3a5
parent 16188 6b52963ced73
child 16232 877aea86fb73
--- a/hgext/mq.py	Sun Feb 26 17:12:15 2012 +0100
+++ b/hgext/mq.py	Tue Feb 28 21:17:53 2012 -0600
@@ -1930,7 +1930,7 @@
     return 0
 
 @command("qapplied",
-         [('1', 'last', None, _('show only the last patch'))
+         [('1', 'last', None, _('show only the preceding applied patch'))
           ] + seriesopts,
          _('hg qapplied [-1] [-s] [PATCH]'))
 def applied(ui, repo, patch=None, **opts):
@@ -2225,7 +2225,7 @@
 
 @command("qprev", seriesopts, _('hg qprev [-s]'))
 def prev(ui, repo, **opts):
     """print the name of the previous applied patch
 
     Returns 0 on success."""
     q = repo.mq
@@ -2225,7 +2225,7 @@
 @command("qprev", seriesopts, _('hg qprev [-s]'))
 def prev(ui, repo, **opts):
-    """print the name of the previous applied patch
+    """print the name of the preceding applied patch
 
     Returns 0 on success."""